@@ -2,7 +2,7 @@
 
 import GeoIP
 
-gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPCity.dat",GeoIP.GEOIP_STANDARD)
+gi = GeoIP.open("/var/db/GeoIP/GeoIPCity.dat",GeoIP.GEOIP_STANDARD)
 
 gir = gi.record_by_name("www.google.com")
 #gir = gi.record_by_addr("24.24.24.24")
