@@ -3,7 +3,7 @@
 import GeoIP
 
 # open the citydatabase. All cities return in iso-8859-1 by default
-gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPCity.dat",GeoIP.GEOIP_STANDARD)
+gi = GeoIP.open("/var/db/GeoIP/GeoIPCity.dat",GeoIP.GEOIP_STANDARD)
 
 # lookup a record, where cityname contains chars > 127 ( eg != ascii )
 gir = gi.record_by_name("www.osnabrueck.de")
