@@ -2,7 +2,7 @@
 
 import GeoIP
 
-gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPNetspeed.dat",GeoIP.GEOIP_STANDARD)
+gi = GeoIP.open("/var/db/GeoIP/GeoIPNetspeed.dat",GeoIP.GEOIP_STANDARD)
 
 # GEOIP_UNKNOWN_SPEED, GEOIP_DIALUP_SPEED, GEOIP_CABLEDSL_SPEED or
 # GEOIP_CORPORATE_SPEED
