@@ -2,7 +2,7 @@
 
 import GeoIP
 
-gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPOrg.dat",GeoIP.GEOIP_STANDARD)
+gi = GeoIP.open("/var/db/GeoIP/GeoIPOrg.dat",GeoIP.GEOIP_STANDARD)
 
 print gi.org_by_name("yahoo.com")
 print gi.org_by_name("www.google.com")
