@@ -2,7 +2,7 @@
 
 import GeoIP
 
-gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPRegion.dat",GeoIP.GEOIP_STANDARD)
+gi = GeoIP.open("/var/db/GeoIP/GeoIPRegion.dat",GeoIP.GEOIP_STANDARD)
 
 gir = gi.region_by_name("www.google.com")
 if gir != None:
